# -*- coding: utf-8 -*-
import dateparser
import scrapy
import traceback
from .base import BaseSpider
from ..items import ExaItem


class MobiHealthNewsSpider(BaseSpider):
    name = "mhn"
    allowed_domains = ["www.mobihealthnews.com"]

    def start_requests(self):
        for i in self.companies(self.name):
            try:
                yield scrapy.Request(i.url + '/', callback=self.parse, meta={'company': i, 'post_id': 0})
            except:
                pass

    def parse(self, response):
        try:
            rows = response.xpath("..//div[contains(@class, 'group-left')]//div[contains(@class, 'views-row')]")
            company = response.meta['company']
            is_duplicate = False
            for i in rows:
                item = ExaItem()
                item['date'] = self.format_date(i.xpath(".//span/span[contains(@class, 'day_list')]/text()").extract_first())
                item['title'] = i.xpath(".//span/a/text()").extract_first()
                item['description'] = i.xpath(".//div[contains(@class, 'views-field views-field-body')]/span/text()").extract_first()
                item['url'] = 'http://www.mobihealthnews.com' + i.xpath(".//span/a/@href").extract_first()

                item.update(self.get_common_items(company))

                item['post_id'] = response.meta['post_id']

                if self.pipeline.check_url(item['url']):
                    is_duplicate = True
                    break
                else:
                    yield scrapy.Request(item['url'], callback=self.parse_tags, meta={'item': item})
            has_next = response.xpath(
                "..//div[contains(@class, 'text-center')]/ul/li[contains(@class, 'next')]/a/text()").extract_first()
            next_url = 'http://www.mobihealthnews.com' + response.xpath(
                "..//div[contains(@class, 'text-center')]/ul/li[contains(@class, 'next')]/a/@href").extract_first()
            print("COUNT", is_duplicate)
            if self.can_follow(has_next, is_duplicate):
                yield scrapy.Request(next_url, callback=self.parse, meta=response.meta)
            else:
                print("DUPLICATE NEWS")

        except BaseException as e:
            print('We had error')
            print(response.url)
            traceback.print_exc()

    def parse_tags(self, response):
        item = response.meta['item']
        item['tags'] = response.xpath(".//div[@class='bottom-tags field field-name-field-tags field-type-taxonomy-term-reference field-label-inline clearfix']//a/text()").extract()
        yield item

